package sexplib

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module type Macro.Sexp_loader

A version of load_sexps that is functorized with respect to the functions that load the sexps from files and the corresponding monad.

module Monad : sig ... end
val load_sexps : string -> Sexp.t list Monad.t
val load_annotated_sexps : string -> Sexp.Annotated.t list Monad.t